django\_kubernetes\_manager package
===================================

Subpackages
-----------

.. toctree::

   django_kubernetes_manager.migrations
   django_kubernetes_manager.models

Submodules
----------

django\_kubernetes\_manager.admin module
----------------------------------------

.. automodule:: django_kubernetes_manager.admin
   :members:
   :undoc-members:
   :show-inheritance:

django\_kubernetes\_manager.serializers module
----------------------------------------------

.. automodule:: django_kubernetes_manager.serializers
   :members:
   :undoc-members:
   :show-inheritance:

django\_kubernetes\_manager.urls module
---------------------------------------

.. automodule:: django_kubernetes_manager.urls
   :members:
   :undoc-members:
   :show-inheritance:

django\_kubernetes\_manager.utils module
----------------------------------------

.. automodule:: django_kubernetes_manager.utils
   :members:
   :undoc-members:
   :show-inheritance:

django\_kubernetes\_manager.views module
----------------------------------------

.. automodule:: django_kubernetes_manager.views
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: django_kubernetes_manager
   :members:
   :undoc-members:
   :show-inheritance:
